pub struct TestingRunner { /* private fields */ }Implementations
Sourceimpl TestingRunner
impl TestingRunner
pub fn new<T>( app: impl Into<AppComponent>, size: Size2D, hook: impl FnOnce(&mut Runner) -> T, scale_factor: f64, ) -> (Self, T)
pub fn set_fonts(&mut self, fonts: HashMap<&str, &[u8]>)
pub fn set_default_fonts(&mut self, fonts: &[Cow<'static, str>])
pub async fn handle_events(&mut self)
pub fn handle_events_immediately(&mut self)
pub fn sync_and_update(&mut self)
Sourcepub fn poll(&mut self, step: Duration, duration: Duration)
pub fn poll(&mut self, step: Duration, duration: Duration)
Poll async tasks and events every step time for a total time of duration.
This is useful for animations for instance.
Sourcepub fn poll_n(&mut self, step: Duration, times: u32)
pub fn poll_n(&mut self, step: Duration, times: u32)
Poll async tasks and events every step, N times.
This is useful for animations for instance.
pub fn send_event(&mut self, platform_event: PlatformEvent)
pub fn move_cursor(&mut self, cursor: impl Into<CursorPoint>)
pub fn write_text(&mut self, text: impl ToString)
pub fn press_key(&mut self, key: Key)
pub fn press_cursor(&mut self, cursor: impl Into<CursorPoint>)
pub fn release_cursor(&mut self, cursor: impl Into<CursorPoint>)
pub fn click_cursor(&mut self, cursor: impl Into<CursorPoint>)
pub fn scroll( &mut self, cursor: impl Into<CursorPoint>, scroll: impl Into<CursorPoint>, )
pub fn animation_clock(&mut self) -> &mut AnimationClock
pub fn render(&mut self) -> SkData
pub fn render_to_file(&mut self, path: impl Into<PathBuf>)
pub fn find<T>( &self, matcher: impl Fn(TestingNode, &dyn ElementExt) -> Option<T>, ) -> Option<T>
pub fn find_many<T>( &self, matcher: impl Fn(TestingNode, &dyn ElementExt) -> Option<T>, ) -> Vec<T>